module complete_ssh_m

  implicit none

contains

  subroutine complete_ssh(ssh_lev, n_cont)

    ! This procedure completes the array ssh_lev by dividing the
    ! largest intervals between values of ssh_lev.

    use jumble, only: ediff1d

    real, intent(inout):: ssh_lev(:) ! (n_max_cont)
    ! Defined only for subscripts 1:n_cont.

    integer, intent(inout):: n_cont
    ! On entry, 2 <= n_cont <= n_max_cont - 1. On return, 2 <= n_cont
    ! <= n_max_cont.

    ! Local:

    integer sort_ssh(size(ssh_lev)) ! (n_max_cont)
    ! Sorts ssh_lev in ascending order. Defined only for subscripts
    ! 1:n_cont.

    real delta_ssh(size(ssh_lev) - 1) ! (n_max_cont - 1)
    integer i
    integer n_max_cont ! >= 3
    real delta_ssh_new
    real, parameter:: delta_ssh_min = 1e-3 ! in m

    !--------------------------------------------------------

    n_max_cont = size(ssh_lev)
    
    if (ssh_lev(1) < ssh_lev(2)) then
       ! Cyclone
       sort_ssh(:n_cont) = [(i, i = 1, n_cont)]
       i = 1
    else
       ! Anticyclone
       sort_ssh(:n_cont) = [(i, i = n_cont, 1, - 1)]
       i = n_cont - 1
    end if

    delta_ssh(:n_cont - 1) = ediff1d(ssh_lev(sort_ssh(:n_cont)))

    do
       delta_ssh_new = delta_ssh(i) / 2.
       if (n_cont == n_max_cont .or. delta_ssh_new < delta_ssh_min) exit
       n_cont = n_cont + 1
       ssh_lev(n_cont) = ssh_lev(sort_ssh(i)) + delta_ssh_new
       sort_ssh(i + 1:n_cont) = [n_cont, sort_ssh(i + 1:n_cont - 1)]
       delta_ssh(i:n_cont - 1) &
            = [delta_ssh_new, delta_ssh_new, delta_ssh(i + 1:n_cont - 2)]
       i = maxloc(delta_ssh(:n_cont - 1), dim = 1)
    end do

  end subroutine complete_ssh
  
end module complete_ssh_m
